torch-contrib
=============

This repository contains reviewed implementations of ideas from recent machine learning papers.

Installation
============

pip:

.. code:: bash

    pip install torchcontrib

From source:

.. code:: bash

    python setup.py install
